@@ -91,7 +91,7 @@ def find(infile, lat, lng, tz='EST', leaveroom=False):
                   if row['irrad'] > NIGHT_CONST or not SKIP_NIGHT]
     
     # Build the new array
-    extra_cols = data_cols + (('AOD', 'cloud') if leaveroom else ())
+    extra_cols = data_cols + (('AOD', 'cloud', 'err') if leaveroom else ())
     clean = empty(len(light_rows),
         dtype=[
             ('time', datetime.datetime), ('clear', bool),
